Installation instructions — BioSimulators-MASSpy 0.0.5 documentation

# Installation instructions

BioSimulators-MASSpy is available as a command-line program and as a command-line program encapsulated into a Docker image.

## Command-line program

After installing Python (>= 3.7), pip, libncurses and libXML, run the following command to install BioSimulators-MASSpy:

    pip install biosimulators-masspy

## Docker image with a command-line entrypoint

After installing Docker, run the following command to install the Docker image for BioSimulators-MASSpy:

    docker pull ghcr.io/biosimulators/masspy